summaryrefslogtreecommitdiffstats
path: root/source/slangc/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'source/slangc/main.cpp')
-rw-r--r--source/slangc/main.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/slangc/main.cpp b/source/slangc/main.cpp
index c7cca428b..75e68ce58 100644
--- a/source/slangc/main.cpp
+++ b/source/slangc/main.cpp
@@ -83,12 +83,12 @@ SLANG_TEST_TOOL_API SlangResult innerMain(StdWriters* stdWriters, slang::IGlobal
// Assume we will used the shared session
ComPtr<slang::IGlobalSession> session(sharedSession);
- // The sharedSession always has a pre-loaded stdlib, is sharedSession is not nullptr.
- // This differed test checks if the command line has an option to setup the stdlib.
- // If so we *don't* use the sharedSession, and create a new stdlib-less session just for this compilation.
- if (TestToolUtil::hasDeferredStdLib(Index(argc - 1), argv + 1))
+ // The sharedSession always has a pre-loaded core module, is sharedSession is not nullptr.
+ // This differed test checks if the command line has an option to setup the core module.
+ // If so we *don't* use the sharedSession, and create a new session without the core module just for this compilation.
+ if (TestToolUtil::hasDeferredCoreModule(Index(argc - 1), argv + 1))
{
- SLANG_RETURN_ON_FAIL(slang_createGlobalSessionWithoutStdLib(SLANG_API_VERSION, session.writeRef()));
+ SLANG_RETURN_ON_FAIL(slang_createGlobalSessionWithoutCoreModule(SLANG_API_VERSION, session.writeRef()));
}
else if (!session)
{